# Changelog

Version 0.3:
  - Renamed from `catcoocc` to `asymcat`, to better reflect the
    functionality of the library

Version 0.2.2:
  - Added function for inverting a scorer

Version 0.2.1:

  - Added basic functions for double series correlation